@@ -95,11 +95,11 @@ pub mod dp {
         } else {
             let length = arr.len();
             let offset: i32 =
-                (max(arr.iter().min().unwrap().abs() + 1, min(value, 0).abs() + 1)) as i32;
+                (max(arr.iter().min().unwrap().abs() + 1, min(value, 0).abs() + 1)) as u32 as i32;
             // We will transform the array into a new array whose elements are all positive.
             // And check if the transformed sum of the result of the new array is equal to the target value.
             // If we find the sum is the same as the target, we will return the result.
-            (1..min(length, max_length) + 1).into_par_iter().for_each(|i| {
+            let c = |i| {
                 let result = _find_subset_fast_only_positive(
                     &arr.iter().map(|e| (e + offset) as u32).collect::<Vec<u32>>(),
                     (value + i as i32 * offset) as usize,
@@ -116,7 +116,12 @@ pub mod dp {
                         answer.lock().unwrap().push(new_res);
                     }
                 }
-            });
+            };
+            if cfg!(feature="wasm"){
+                (1..min(length, max_length) + 1).into_iter().for_each(c);
+            } else {
+                (1..min(length, max_length) + 1).into_par_iter().for_each(c);
+            }
             return vector_sorter(answer.lock().unwrap().to_vec());
         };
     }
@@ -354,7 +359,7 @@ pub mod dp {
     /// ```rust
     ///
     ///use dpss::dp::sequence_matcher;
-    ///let answer = sequence_matcher(&mut vec![1980, 2980, 3500, 4000, 1050], &mut vec![1950, 2900, 30, 80, 3300, 200, 3980, 1050, 20], 10, 10, 2);
+    ///let answer = sequence_matcher(&mut vec![1980, 2980, 3500, 4000, 1050], &mut vec![1950, 2900, 30, 80, 3300, 200, 3980, 1050, 20], 10, 10, 100);
     ///assert_eq!(answer[0], vec![
     ///    (vec![1050],
     ///     vec![1050]),
@@ -373,17 +378,17 @@ pub mod dp {
     ///
     ///    ]);
     ///assert_eq!(answer[1], vec![
-    ///    (vec![1980],
+    ///    (vec![1050],
+    ///     vec![1050]),
+    ///
+    ///     (vec![1980],
     ///     vec![30, 1950]),
     ///
     ///     (vec![2980],
     ///     vec![80, 2900]),
     ///
-    ///     (vec![3500],
-    ///     vec![200, 3300]),
-    ///
-    ///     (vec![1050, 4000],
-    ///     vec![20, 1050, 3980]),
+    ///     (vec![3500, 4000],
+    ///     vec![20, 200, 3300, 3980]),
     ///
     ///    ]);
     /// ```
@@ -460,57 +465,111 @@ pub mod dp {
         let mc = MultiCombination{
             combs: combs,
         };
-        mc.par_bridge().for_each(|i| {
-            let mut sum_key = 0;
-            let mut vec_key = vec![];
-            for j in i.iter() {
-                sum_key += keys[*j];
-                vec_key.push(keys[*j].clone());
-            }
-            vec_key.sort();
-            if sum_key > targets.iter().sum() {
-                return;
-            }
-            if sum_key < *targets.iter().min().unwrap() {
-                return;
-            }
-            if targets.iter().max().unwrap() == &0 {
-                return;
-            }
-            let mut set_ = match hashmap_fs.try_lock() {
-                Ok(mut v) => {v.entry((targets.clone(), sum_key))
-                    .or_insert(find_subset(targets.clone(), sum_key, max_target_length))
-                    .clone()},
-                Err(_) => {find_subset(targets.clone(), sum_key, max_target_length)}
-            };
-            if set_.len() == 0 {
-                return;
-            }
-            set_.sort();
-            set_.dedup();
-            set_.par_iter().for_each(|set| {
-                let mut keys3 = keys.clone();
-                let mut targets3 = targets.clone();
-                let mut group3 = group.clone();
-                group3.push((vec_key.clone(), set.clone()));
-                for j in set.clone() {
-                    vec_remove(&mut targets3, j);
+        if cfg!(feature="wasm") {
+            mc.for_each(|i| {
+                let mut sum_key = 0;
+                let mut vec_key = vec![];
+                for j in i.iter() {
+                    sum_key += keys[*j];
+                    vec_key.push(keys[*j].clone());
                 }
-                for i in vec_key.clone() {
-                    vec_remove(&mut keys3, i);
+                vec_key.sort();
+                if sum_key > targets.iter().sum() {
+                    return;
                 }
-                sequence_matcher_core(
-                    &mut keys3,
-                    &mut targets3,
-                    &mut group3,
-                    &mut answer.clone(),
-                    max_key_length,
-                    max_target_length,
-                    &mut hashmap_fs.clone(),
-                    n_candidates
-                );
+                if sum_key < *targets.iter().min().unwrap() {
+                    return;
+                }
+                if targets.iter().max().unwrap() == &0 {
+                    return;
+                }
+                let mut set_ = match hashmap_fs.try_lock() {
+                    Ok(mut v) => {v.entry((targets.clone(), sum_key))
+                        .or_insert(find_subset(targets.clone(), sum_key, max_target_length))
+                        .clone()},
+                    Err(_) => {find_subset(targets.clone(), sum_key, max_target_length)}
+                };
+                if set_.len() == 0 {
+                    return;
+                }
+                set_.sort();
+                set_.dedup();
+                set_.iter().for_each(|set| {
+                    let mut keys3 = keys.clone();
+                    let mut targets3 = targets.clone();
+                    let mut group3 = group.clone();
+                    group3.push((vec_key.clone(), set.clone()));
+                    for j in set.clone() {
+                        vec_remove(&mut targets3, j);
+                    }
+                    for i in vec_key.clone() {
+                        vec_remove(&mut keys3, i);
+                    }
+                    sequence_matcher_core(
+                        &mut keys3,
+                        &mut targets3,
+                        &mut group3,
+                        &mut answer.clone(),
+                        max_key_length,
+                        max_target_length,
+                        &mut hashmap_fs.clone(),
+                        n_candidates
+                    );
+                });
             });
-        });
+        } else {
+            mc.par_bridge().for_each(|i| {
+                let mut sum_key = 0;
+                let mut vec_key = vec![];
+                for j in i.iter() {
+                    sum_key += keys[*j];
+                    vec_key.push(keys[*j].clone());
+                }
+                vec_key.sort();
+                if sum_key > targets.iter().sum() {
+                    return;
+                }
+                if sum_key < *targets.iter().min().unwrap() {
+                    return;
+                }
+                if targets.iter().max().unwrap() == &0 {
+                    return;
+                }
+                let mut set_ = match hashmap_fs.try_lock() {
+                    Ok(mut v) => {v.entry((targets.clone(), sum_key))
+                        .or_insert(find_subset(targets.clone(), sum_key, max_target_length))
+                        .clone()},
+                    Err(_) => {find_subset(targets.clone(), sum_key, max_target_length)}
+                };
+                if set_.len() == 0 {
+                    return;
+                }
+                set_.sort();
+                set_.dedup();
+                set_.par_iter().for_each(|set| {
+                    let mut keys3 = keys.clone();
+                    let mut targets3 = targets.clone();
+                    let mut group3 = group.clone();
+                    group3.push((vec_key.clone(), set.clone()));
+                    for j in set.clone() {
+                        vec_remove(&mut targets3, j);
+                    }
+                    for i in vec_key.clone() {
+                        vec_remove(&mut keys3, i);
+                    }
+                    sequence_matcher_core(
+                        &mut keys3,
+                        &mut targets3,
+                        &mut group3,
+                        &mut answer.clone(),
+                        max_key_length,
+                        max_target_length,
+                        &mut hashmap_fs.clone(),
+                        n_candidates
+                    );
+                });
+            });
+        }
         ()
     }
 
